@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11979 2020-03-18 04:52:03Z Trista $
+# $Id: __init__.py 12001 2020-03-24 16:45:06Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-03-18 12:52:03 +0800 (週三, 18 三月 2020) $
-# $Revision: 11979 $
+# $Date: 2020-03-25 00:45:06 +0800 (週三, 25 三月 2020) $
+# $Revision: 12001 $
 
 from django.conf import settings as _settings
 from django.utils.translation import ugettext_lazy as _
@@ -41,6 +41,17 @@ class settings(object):
         for ele in _settings.ZEPHYRUS_BLOG_DATE_TEMPLATES:
             if not ele[0] == ZEPHYRUS_BLOG_MAYLIKE_DEFAULT_TEMPLATE:
                 ZEPHYRUS_BLOG_DATE_TEMPLATES.append(ele)
+    
+    CALL_TO_ACTION_EMAIL_SUBJECT = f'Your Special File arrived'
+    
+    if hasattr(_settings, 'CALL_TO_ACTION_EMAIL_SUBJECT'):
+        CALL_TO_ACTION_EMAIL_SUBJECT = _settings.CALL_TO_ACTION_EMAIL_SUBJECT 
+    
+    CALL_TO_ACTION_PDF_DEFAULT_TEMPLATE = 'blog_extension/call_to_action/PDFBase.html'
+    if hasattr(_settings, 'CALL_TO_ACTION_PDF_BASE_TEMPLATE'):
+        CALL_TO_ACTION_PDF_BASE_TEMPLATE = _settings.CALL_TO_ACTION_PDF_BASE_TEMPLATE
+    else:
+        CALL_TO_ACTION_PDF_BASE_TEMPLATE = CALL_TO_ACTION_PDF_DEFAULT_TEMPLATE
                 
                 
     THANK_DEFAULT_TEMPLATE = 'landing/ThankYou.html'
@@ -58,7 +69,7 @@ class settings(object):
         "blog_extension/call_to_action/Default.html"
 
     CALL_TO_ACTION_TEMPLATES = [
-        (CALL_TO_ACTION_DEFAULT_TEMPLATE, _("Default")),
+        (CALL_TO_ACTION_DEFAULT_TEMPLATE, _("Default Call To Action Template")),
     ]
 
     if hasattr(_settings, 'CALL_TO_ACTION_TEMPLATES'):
@@ -70,7 +81,7 @@ class settings(object):
         "blog_extension/call_to_action/DefaultForm.html"
 
     CALL_TO_ACTION_FORM_TEMPLATES = [
-        (CALL_TO_ACTION_FORM_DEFAULT_TEMPLATE, _("Default")),
+        (CALL_TO_ACTION_FORM_DEFAULT_TEMPLATE, _("Default Call To Action Form Template")),
     ]
 
     if hasattr(_settings, 'CALL_TO_ACTION_FORM_TEMPLATES'):
