@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_dumpdata.py 11461 2019-04-16 18:26:42Z Lavender $
+# $Id: cms_dumpdata.py 12002 2020-03-24 16:46:06Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2019-04-17 03:26:42 +0900 (週三, 17 四月 2019) $
-# $Revision: 11461 $
+# $Author: Trista $
+# $Date: 2020-03-25 00:46:06 +0800 (週三, 25 三月 2020) $
+# $Revision: 12002 $
 
 import os
 import sys
@@ -75,49 +75,68 @@ class Command(BaseCommand):
                 
         filerData = json.loads(dataStream.getvalue())
         
-        os.system(
-            "%s manage.py dumpdata -e auth.Permission auth > authData.json" %  
-            sys.executable)
+        try:
+        
+            os.system(
+                "%s manage.py dumpdata -e auth.Permission auth > authData.json" %  
+                sys.executable)
+
+            os.system(
+                "%s manage.py dumpdata cms.Treenode > treenodeData.json" %  
+                sys.executable)
+                
+            os.system(
+                ("%s manage.py dumpdata "
+                 "-e auth -e sites -e filer -e "
+                 "contenttypes -e cms.Treenode"
+                 "> otherData.json") % 
+                 sys.executable)
+        
+            with open('authData.json') as f:
+                content = f.read()
+                authData = json.loads(content[content.index('['):])
+            with open('treenodeData.json') as f:
+                content = f.read()
+                treenodeData = json.loads(content[content.index('['):])
+            with open('otherData.json') as f:
+                content = f.read()
+                otherData = json.loads(content[content.index('['):])
+
+            data = []
+
+            if not options['noAuth']:
+                for ele in authData:
+                    data.append(ele)
 
-        os.system(
-            "%s manage.py dumpdata cms.Treenode > treenodeData.json" %  
-            sys.executable)
             
-        os.system(
-            ("%s manage.py dumpdata "
-             "-e auth -e sites -e filer -e "
-             "contenttypes -e cms.Treenode"
-             "> otherData.json") % 
-             sys.executable)
-        
-        with open('authData.json') as f:
-            content = f.read()
-            authData = json.loads(content[content.index('['):])
-        with open('treenodeData.json') as f:
-            content = f.read()
-            treenodeData = json.loads(content[content.index('['):])
-        with open('otherData.json') as f:
-            content = f.read()
-            otherData = json.loads(content[content.index('['):])
-
-        data = []
-
-        if not options['noAuth']:
-            for ele in authData:
+            for ele in filerData:
                 data.append(ele)
+            for ele in treenodeData:
+                data.append(ele)
+            for ele in otherData:
+                data.append(ele)
+            
 
+            path = os.path.join(options['path'])
+
+            with open(path, 'w') as f:
+                content = f.write(json.dumps(data))
+            # os.remove('authData.json')
+            # os.remove('treenodeData.json')
+            # os.remove('otherData.json')
+            
+        finally:
+        
+            if os.path.exists('authData.json'):
+                os.remove('authData.json')
+                
+            if os.path.exists('treenodeData.json'):
+                os.remove('treenodeData.json')
+                
+            if os.path.exists('otherData.json'):
+                os.remove('otherData.json')
+                
+            path = os.path.join(options['path'])
+            if os.path.exists(path):
+                os.remove(path)
         
-        for ele in filerData:
-            data.append(ele)
-        for ele in treenodeData:
-            data.append(ele)
-        for ele in otherData:
-            data.append(ele)
-
-        path = os.path.join(options['path'])
-
-        with open(path, 'w') as f:
-            content = f.write(json.dumps(data))
-        os.remove('authData.json')
-        os.remove('treenodeData.json')
-        os.remove('otherData.json')
