@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11936 2020-02-19 07:31:27Z Lavender $
+# $Id: models.py 11977 2020-03-16 18:37:48Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,17 +12,21 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-02-19 15:31:27 +0800 (週三, 19 二月 2020) $
-# $Revision: 11936 $
+# $Date: 2020-03-17 02:37:48 +0800 (週二, 17 三月 2020) $
+# $Revision: 11977 $
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 from django.core.validators import MaxValueValidator, MinValueValidator
+from solo.models import SingletonModel
 
 from cms.models import CMSPlugin
 
 from Zephyrus.facebook import settings
 
+class FacebookSettings(SingletonModel):
+    accessToken = models.CharField(_('Access token'), max_length=512, blank=True, null=True, default=None)
+
 class FacebookFan(CMSPlugin):
     url = models.URLField(max_length=400)
     limit = models.PositiveIntegerField(default=0, 
